@@ -27,8 +27,6 @@ struct _EogImagePrivate {
 	gint width;
 	gint height;
 	GnomeVFSFileSize bytes;
-	GnomeVFSMonitorHandle *monitor_handle;
-	gpointer toclean;
 	char *file_type;
 
 	guchar  *exif_chunk; /* holds EXIF raw data */
@@ -52,6 +50,7 @@ struct _EogImagePrivate {
 	gchar *caption_key;
 
 	GThread *load_thread;
+	GMutex *mutex;
 	GMutex *status_mutex;
 	GCond  *load_finished;
 	gboolean cancel_loading;
