@@ -1,6 +1,5 @@
 #include <config.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-macros.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "eog-info-view.h"
@@ -108,13 +107,11 @@ update_data_pages_for_image (EogInfoView *view, EogImage *image)
 	g_return_if_fail (EOG_IS_IMAGE (image));
 	
 	eog_info_view_file_show_data (EOG_INFO_VIEW_FILE (view->priv->file_view), image);
-	eog_image_register_infoview (image, EOG_INFO_VIEW_FILE (view->priv->file_view));
 #if HAVE_EXIF
 	{
 		ExifData *ed;
 
 		ed = eog_image_get_exif_information (image);
-		g_print ("Show exif data\n");
 		eog_info_view_exif_show_data (EOG_INFO_VIEW_EXIF (view->priv->exif_view), ed);
 		if (ed != NULL) {
 			gtk_widget_show_all (gtk_widget_get_parent (GTK_WIDGET (view->priv->exif_view)));
